==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/marketplace/messages/th/base.php <==
<?php

return [
    '
Module successfully disabled!
' => 'ปิดการใช้งานโมดูลสำเร็จแล้ว',
    '
Module successfully enabled!
' => 'เปิดใช้งานโมดูลสำเร็จแล้ว',
    '
No active Professional Edition license found!
' => 'ไม่พบใบอนุญาต Professional Edition ที่ใช้งานอยู่',
    '
PROFESSIONAL EDITION
' => 'รุ่นมืออาชีพ',
    '
The license could not be activated:
' => 'ไม่สามารถเปิดใช้งานใบอนุญาตได้:',
    '
The license was successfully activated!

' => 'เปิดใช้งานใบอนุญาตสำเร็จแล้ว',
    '
The license was successfully removed!

' => 'ใบอนุญาตถูกลบออกเรียบร้อยแล้ว',
    '--- Disable module: {moduleId} ---

' => '--- ปิดการใช้งานโมดูล: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- เปิดใช้งานโมดูล: {moduleId} ---',
    '<strong>Activate</strong> your Professional Edition' => '<strong>เปิดใช้งาน</strong> Professional Edition ของคุณ',
    'Add purchased module by licence key' => 'เพิ่มโมดูลที่ซื้อด้วยรหัสใบอนุญาต',
    'All {moduleId} module content will be deleted. Continue?' => 'เนื้อหาโมดูล {moduleId} ทั้งหมดจะถูกลบออก ดำเนินการต่อ',
    'Buy' => 'ซื้อ',
    'Buy (%price%)' => 'ซื้อ (%ราคา%)',
    'Could not connect to HumHub API!
' => 'ไม่สามารถเชื่อมต่อกับ HumHub API!',
    'Could not connect to licence server!' => 'ไม่สามารถเชื่อมต่อกับเซิร์ฟเวอร์ใบอนุญาต',
    'Could not extract module!' => 'ไม่สามารถแยกโมดูลได้',
    'Could not remove old module path!' => 'ไม่สามารถลบเส้นทางโมดูลเก่า',
    'Could not update licence. Error: ' => 'ไม่สามารถอัปเดตใบอนุญาต ข้อผิดพลาด:',
    'Download of module failed!' => 'การดาวน์โหลดโมดูลล้มเหลว',
    'Edit licence' => 'แก้ไขใบอนุญาต',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'หากโมดูลนี้ถูกทำเครื่องหมายเพิ่มเติมเป็น <strong>"ชุมชน"</strong> จะไม่ได้รับการทดสอบหรือตรวจสอบโดยทีมงานโครงการ HumHub',
    'Install' => 'ติดตั้ง',
    'Installed' => 'ติดตั้งแล้ว',
    'Installing module...' => 'กำลังติดตั้งโมดูล...',
    'Invalid module licence key!
' => 'รหัสใบอนุญาตโมดูลไม่ถูกต้อง',
    'Latest version:' => 'รุ่นล่าสุด:',
    'Licence Key:' => 'รหัสใบอนุญาต:',
    'Licence key' => 'รหัสใบอนุญาต',
    'Licenced for max. {number} users.' => 'ได้รับอนุญาตสูงสุด {number} ผู้ใช้',
    'Licenced to:' => 'ได้รับอนุญาตให้:',
    'Marketplace' => 'ตลาดกลาง',
    'Max. users:' => 'แม็กซ์ ผู้ใช้:',
    'Module directory %modulePath% is not writeable!' => 'ไดเรกทอรีโมดูล %modulePath% ไม่สามารถเขียนได้',
    'Module download failed! (%error%)' => 'การดาวน์โหลดโมดูลล้มเหลว! (%ผิดพลาด%)',
    'Module licence added!
' => 'เพิ่มใบอนุญาตโมดูลแล้ว',
    'Module licence key cannot be empty!
' => 'รหัสใบอนุญาตของโมดูลไม่สามารถเว้นว่างได้',
    'Module not found or activated!
' => 'ไม่พบโมดูลหรือเปิดใช้งาน',
    'Module not found!
' => 'ไม่พบโมดูล',
    'More info' => 'ข้อมูลเพิ่มเติม',
    'No compatible module version found!' => 'ไม่พบเวอร์ชันโมดูลที่เข้ากันได้!',
    'No license key? Find out more about the {pro} or contact us.' => 'ไม่มีคีย์ใบอนุญาต? ค้นหาข้อมูลเพิ่มเติมเกี่ยวกับ {pro} หรือติดต่อเรา',
    'No purchased modules found!' => 'ไม่พบโมดูลที่ซื้อ',
    'Ok' => 'ตกลง',
    'Professional Edition is activated!' => 'เปิดใช้งานรุ่นมืออาชีพแล้ว',
    'Register' => 'ลงทะเบียน',
    'Remove licence key' => 'ลบรหัสใบอนุญาต',
    'Save and update' => 'บันทึกและอัปเดต',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'โปรเจ็กต์ HumHub ไม่รับประกันการทำงาน คุณภาพ หรือการพัฒนาอย่างต่อเนื่องของโมดูลนี้',
    'Third-party' => 'บุคคลที่สาม',
    'Third-party Modules are not covered by Professional Edition agreements.' => 'โมดูลของบริษัทอื่นไม่อยู่ภายใต้ข้อตกลงรุ่น Profession',
    'Third-party disclaimer' => 'ข้อจำกัดความรับผิดชอบของบุคคลที่สาม',
    'This Module was developed by a third-party.' => 'โมดูลนี้ได้รับการพัฒนาโดยบุคคลที่สาม',
    'Update' => 'อัพเดท',
    'Upgrade to Professional Edition' => 'อัปเกรดเป็น Professional Edition',
    'Version:' => 'รุ่น:',
    'A new update is available (HumHub %version%)!' => '',
    'Add Licence Key' => '',
    'All' => '',
    'Available Updates' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Featured' => '',
    'Learn more' => '',
    'New' => '',
    'Not Installed' => '',
    'Official' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Stop updating' => '',
    'Tags' => '',
    'Update all' => '',
    'Your HumHub installation is up to date!' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/marketplace/messages/th/base.php <==
<?php

return [
    '
Module successfully disabled!
' => 'ปิดการใช้งานโมดูลสำเร็จแล้ว',
    '
Module successfully enabled!
' => 'เปิดใช้งานโมดูลสำเร็จแล้ว',
    '
No active Professional Edition license found!
' => 'ไม่พบใบอนุญาต Professional Edition ที่ใช้งานอยู่',
    '
The license could not be activated:
' => 'ไม่สามารถเปิดใช้งานใบอนุญาตได้:',
    '
The license was successfully activated!

' => 'เปิดใช้งานใบอนุญาตสำเร็จแล้ว',
    '
The license was successfully removed!

' => 'ใบอนุญาตถูกลบออกเรียบร้อยแล้ว',
    '--- Disable module: {moduleId} ---

' => '--- ปิดการใช้งานโมดูล: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- เปิดใช้งานโมดูล: {moduleId} ---',
    '<strong>Activate</strong> your Professional Edition' => '<strong>เปิดใช้งาน</strong> Professional Edition ของคุณ',
    'Activate' => 'เปิดใช้งาน',
    'Activated' => 'เปิดใช้งานแล้ว',
    'Add purchased module by licence key' => 'เพิ่มโมดูลที่ซื้อด้วยรหัสใบอนุญาต',
    'All' => 'ทั้งหมด',
    'All {moduleId} module content will be deleted. Continue?' => 'เนื้อหาโมดูล {moduleId} ทั้งหมดจะถูกลบออก ดำเนินการต่อ',
    'Buy' => 'ซื้อ',
    'Buy (%price%)' => 'ซื้อ (%ราคา%)',
    'Configure' => 'กำหนดค่า',
    'Could not connect to HumHub API!
' => 'ไม่สามารถเชื่อมต่อกับ HumHub API!',
    'Could not connect to licence server!' => 'ไม่สามารถเชื่อมต่อกับเซิร์ฟเวอร์ใบอนุญาต',
    'Could not extract module!' => 'ไม่สามารถแยกโมดูลได้',
    'Could not find requested module!' => 'ไม่พบโมดูลที่ร้องขอ!',
    'Could not remove old module path!' => 'ไม่สามารถลบเส้นทางโมดูลเก่า',
    'Could not update licence. Error: ' => 'ไม่สามารถอัปเดตใบอนุญาต ข้อผิดพลาด:',
    'Download of module failed!' => 'การดาวน์โหลดโมดูลล้มเหลว',
    'Edit licence' => 'แก้ไขใบอนุญาต',
    'General Settings' => 'การตั้งค่าทั่วไป',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'หากโมดูลนี้ถูกทำเครื่องหมายเพิ่มเติมเป็น <strong>"ชุมชน"</strong> จะไม่ได้รับการทดสอบหรือตรวจสอบโดยทีมงานโครงการ HumHub',
    'Information' => 'ข้อมูล',
    'Install' => 'ติดตั้ง',
    'Installed' => 'ติดตั้งแล้ว',
    'Invalid module licence key!
' => 'รหัสใบอนุญาตโมดูลไม่ถูกต้อง',
    'Latest version:' => 'รุ่นล่าสุด:',
    'Licence Key:' => 'รหัสใบอนุญาต:',
    'Licence key' => 'รหัสใบอนุญาต',
    'Licenced for max. {number} users.' => 'ได้รับอนุญาตสูงสุด {number} ผู้ใช้',
    'Licenced to:' => 'ได้รับอนุญาตให้:',
    'License not found or expired. Please contact the module publisher.' => 'ไม่พบใบอนุญาตหรือหมดอายุ โปรดติดต่อผู้เผยแพร่โมดูล',
    'Marketplace' => 'ตลาดกลาง',
    'Max. users:' => 'แม็กซ์ ผู้ใช้:',
    'Module directory %modulePath% is not writeable!' => 'ไดเรกทอรีโมดูล %modulePath% ไม่สามารถเขียนได้',
    'Module download failed! (%error%)' => 'การดาวน์โหลดโมดูลล้มเหลว! (%ผิดพลาด%)',
    'Module licence added!
' => 'เพิ่มใบอนุญาตโมดูลแล้ว',
    'Module licence key cannot be empty!
' => 'รหัสใบอนุญาตของโมดูลไม่สามารถเว้นว่างได้',
    'Module not found or activated!
' => 'ไม่พบโมดูลหรือเปิดใช้งาน',
    'Module not found!
' => 'ไม่พบโมดูล',
    'More info' => 'ข้อมูลเพิ่มเติม',
    'New' => 'ใหม่',
    'No compatible module version found!' => 'ไม่พบเวอร์ชันโมดูลที่เข้ากันได้!',
    'No license key? Find out more about the {pro} or contact us.' => 'ไม่มีคีย์ใบอนุญาต? ค้นหาข้อมูลเพิ่มเติมเกี่ยวกับ {pro} หรือติดต่อเรา',
    'No modules installed yet. Install some to enhance the functionality!' => 'ยังไม่ได้ติดตั้งโมดูล ติดตั้งบางส่วนเพื่อเพิ่มประสิทธิภาพการทำงาน!',
    'No purchased modules found!' => 'ไม่พบโมดูลที่ซื้อ',
    'Ok' => 'ตกลง',
    'Professional Edition is activated!' => 'เปิดใช้งานรุ่นมืออาชีพแล้ว',
    'Register' => 'ลงทะเบียน',
    'Remove licence key' => 'ลบรหัสใบอนุญาต',
    'Save and update' => 'บันทึกและอัปเดต',
    'Search' => 'ค้นหา',
    'Search...' => 'ค้นหา...',
    'Settings' => 'การตั้งค่า',
    'Tags' => 'แท็ก',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'โปรเจ็กต์ HumHub ไม่รับประกันการทำงาน คุณภาพ หรือการพัฒนาอย่างต่อเนื่องของโมดูลนี้',
    'Third-party' => 'บุคคลที่สาม',
    'Third-party Modules are not covered by Professional Edition agreements.' => 'โมดูลของบริษัทอื่นไม่อยู่ภายใต้ข้อตกลงรุ่น Profession',
    'Third-party disclaimer' => 'ข้อจำกัดความรับผิดชอบของบุคคลที่สาม',
    'This Module was developed by a third-party.' => 'โมดูลนี้ได้รับการพัฒนาโดยบุคคลที่สาม',
    'Try other keywords or remove filters.' => 'ลองใช้คำหลักอื่นหรือลบตัวกรอง',
    'Update' => 'อัพเดท',
    'Update successful' => 'อัพเดทสำเร็จ',
    'Upgrade to Professional Edition' => 'อัปเกรดเป็น Professional Edition',
    'Version:' => 'รุ่น:',
    '<strong>General</strong> Settings' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Activate now' => '',
    'Add Licence Key' => '',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => '',
    'Allow module versions in beta status' => '',
    'Available Updates' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!' => '',
    'Could not find the requested module!' => '',
    'Deprecated' => '',
    'Featured' => '',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => '',
    'Great!' => '',
    'Invalid module licence key!' => '',
    'Learn more' => '',
    'Marketplace is disabled.' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'Module <strong>activated</strong>' => '',
    'Module <strong>installed</strong>' => '',
    'Module configuration' => '',
    'Module is <strong>installing...</strong>' => '',
    'Module licence added!' => '',
    'No modules found.' => '',
    'Official' => '',
    'PROFESSIONAL EDITION' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Stop updating' => '',
    'Uninstalled' => '',
    'Update all' => '',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '',
    'Well done! To make the module available within your network, you will also need to activate it. Do you want to activate it now?' => '',
    'Well done! You have successful installed an activated the module!' => '',
    'Would you like to jump straight to it?' => '',
    'Your HumHub installation is up to date!' => '',
];
